###################################################
### chunk number 1: options
###################################################
options(continue = "  ")


###################################################
### chunk number 2: load
###################################################
library(penalized)
library(survival)
data(nki70)


###################################################
### chunk number 3: first
###################################################
fit <- penalized(ER, ~DIAPH3+NUSAP1, data=nki70, lambda2=1)
fit <- penalized(ER, nki70[,10:11], data=nki70, lambda2=1)
fit <- penalized(ER~DIAPH3+NUSAP1, data=nki70, lambda2=1)


###################################################
### chunk number 4: survival
###################################################
fit <- penalized(Surv(time,event)~DIAPH3+NUSAP1, data=nki70, lambda2=1)


###################################################
### chunk number 5: attach
###################################################
attach(nki70)


###################################################
### chunk number 6: extract
###################################################
residuals(fit)[1:10]
fitted.values(fit)[1:10]
basesurv(fit)


###################################################
### chunk number 7: coefficients
###################################################
coefficients(fit, "all")


###################################################
### chunk number 8: predict
###################################################
predict(fit, ~DIAPH3+NUSAP1, data=nki70[1:3,])
predict(fit, nki70[1:3,c("DIAPH3","NUSAP1")])


###################################################
### chunk number 9: weights
###################################################
coefficients(fit)
coefficients(fit, standardize = TRUE)
weights(fit)


###################################################
### chunk number 10: unpenalized
###################################################
fit <- penalized(Surv(time,event), nki70[,8:77], ~ER, lambda2=1)
fit <- penalized(Surv(time,event)~ER, nki70[,8:77], lambda2=1)


###################################################
### chunk number 11: steps
###################################################
fit <- penalized(Surv(time,event), nki70[,8:77], lambda1=1,
    steps=50, trace = FALSE)
plotpath(fit, log="x")


###################################################
### chunk number 12: stepsplot
###################################################
plotpath(fit, log="x")


###################################################
### chunk number 13: positive
###################################################
fit <- penalized(Surv(time,event), nki70[,8:77], positive=TRUE)


###################################################
### chunk number 14: positivecoefficients
###################################################
coefficients(fit)


###################################################
### chunk number 15: positivestepsplot
###################################################
fit <- penalized(Surv(time,event), nki70[,8:77], positive=TRUE,
    steps=50)
plotpath(fit)


###################################################
### chunk number 16: cvl1
###################################################
fit <- cvl(Surv(time,event), nki70[,8:77], lambda1=1, fold=10)


###################################################
### chunk number 17: cvl2
###################################################
fit$cvl
fit$fullfit


###################################################
### chunk number 18: cvl3
###################################################
fit <- cvl(Surv(time,event), nki70[,8:77], lambda1=2, fold=fit$fold)


###################################################
### chunk number 19: breslow
###################################################
fit$predictions
time(fit$predictions)
as.data.frame(basesurv(fit$fullfit))[1:10,]
plot(fit$predictions)


###################################################
### chunk number 20: breslowplot
###################################################
plot(fit$predictions)


###################################################
### chunk number 21: cv-survival
###################################################
survival(fit$predictions, 5)[1:10]


###################################################
### chunk number 22: prof
###################################################
fit1 <- profL1(Surv(time,event), nki70[,50:70], fold=10)
plot(fit1$lambda, fit1$cvl, type="l")
fit2 <- profL2(Surv(time,event), nki70[,50:70], fold=fit1$fold,
    minl = 0.01, maxl = 1000)
plot(fit2$lambda, fit2$cvl, type="l", log="x")


###################################################
### chunk number 23: profplot1
###################################################
plot(fit1$lambda, fit1$cvl, type="l")


###################################################
### chunk number 24: profplot2
###################################################
plot(fit2$lambda, fit2$cvl, type="l", log="x")


###################################################
### chunk number 25: profpath
###################################################
plotpath(fit2$fullfit, log="x")


###################################################
### chunk number 26: profpathplot
###################################################
plotpath(fit2$fullfit, log="x")


###################################################
### chunk number 27: opt1
###################################################
opt1 <- optL1(Surv(time,event), nki70[,50:70], fold=fit1$fold)


###################################################
### chunk number 28: optres
###################################################
opt1$lambda
opt1$cvl


###################################################
### chunk number 29: opt2
###################################################
opt2 <- optL2(Surv(time,event), nki70[,50:70], fold=fit2$fold)


